@@ -476,6 +476,7 @@ void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint /*time
 
     if (useOfflineUpdates() && exit == PackageKit::Transaction::ExitSuccess) {
         PackageKit::Daemon::global()->offline()->trigger(PackageKit::Offline::ActionReboot);
+        enableReadyToReboot();
     }
 }
 
@@ -557,7 +558,7 @@ void PackageKitUpdater::errorFound(PackageKit::Transaction::Error err, const QSt
         || err == PackageKit::Transaction::ErrorNotAuthorized) {
         return;
     }
-    QString finalMessage = xi18nc("@info", "%1:<nl/><nl/>%2", PackageKitMessages::errorMessage(err), error);
+    QString finalMessage = xi18nc("@info", "%1:<nl/><nl/>%2", PackageKitMessages::errorMessage(err, QString()), error);
     Q_EMIT passiveMessage(finalMessage);
     qWarning() << "Error happened" << err << error;
 }
